@@ -13,8 +13,8 @@ class EditProject(FlaskForm):
             Regexp(
                 "^[A-Za-z][A-Za-z0-9_. ]*$",
                 0,
-                "Projects must have only letters, numbers, " + 
-                "dots, spaces, or underscores",
+                "Projects must have only letters, numbers, "
+                + "dots, spaces, or underscores",
             ),
         ],
     )
@@ -31,8 +31,8 @@ class AddProject(FlaskForm):
             Regexp(
                 "^[A-Za-z][A-Za-z0-9_. ]*$",
                 0,
-                "Projects must have only letters, numbers, " + 
-                "dots, spaces, or underscores",
+                "Projects must have only letters, numbers, "
+                + "dots, spaces, or underscores",
             ),
         ],
     )
